<?php
/**
 * Mahara: Electronic portfolio, weblog, resume builder and social networking
 * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
 *                         http://wiki.mahara.org/Contributors
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    mahara
 * @subpackage lang
 * @author     Catalyst IT Ltd
 * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
 * @copyright  (C) 2006-2009 Catalyst IT Ltd http://catalyst.net.nz
 *
 */

defined('INTERNAL') || die();

$string['pluginname'] = 'Journals';

$string['blog'] = 'Journal';
$string['blogs'] = 'Journals';
$string['addblog'] = 'Create journal';
$string['addpost'] = 'New entry';
$string['alignment'] = 'Alignment';
$string['allowcommentsonpost'] = 'Allow comments on your entry.';
$string['allposts'] = 'All entries';
$string['attach'] = 'Attach';
$string['attachedfilelistloaded'] = 'Attached file list loaded';
$string['attachedfiles'] = 'Attached files';
$string['attachment'] = 'Attachment';
$string['attachments'] = 'Attachments';
$string['blogcopiedfromanotherview'] = 'Note: This block has been copied from another page. You may move it around or remove it, but you cannot change what %s is in it.';
$string['blogdesc'] = 'Description';
$string['blogdescdesc'] = 'e.g., ‘A record of Jill\'s experiences and reflections’.';
$string['blogdoesnotexist'] = 'You are trying to access a journal that does not exist';
$string['blogpostdoesnotexist'] = 'You are trying to access a journal entry that does not exist';
$string['blogpost'] = 'Journal entry';
$string['blogdeleted'] = 'Journal deleted';
$string['blogpostdeleted'] = 'Journal entry deleted';
$string['blogpostpublished'] = 'Journal entry published';
$string['blogpostsaved'] = 'Journal entry saved';
$string['blogsettings'] = 'Journal settings';
$string['blogtitle'] = 'Title';
$string['blogtitledesc'] = 'e.g., ‘Jill’s Nursing Practicum Journal’.';
$string['border'] = 'Border';
$string['cancel'] = 'Cancel';
$string['createandpublishdesc'] = 'This will create the journal entry and make it available to others.';
$string['createasdraftdesc'] = 'This will create the journal entry, but it will not become available to others until you choose to publish it.';
$string['createblog'] = 'Create journal';
$string['dataimportedfrom'] = 'Data imported from %s';
$string['defaultblogtitle'] = '%s\'s Journal';
$string['delete'] = 'Delete';
$string['deleteblog?'] = 'Are you sure you want to delete this journal?';
$string['deleteblogpost?'] = 'Are you sure you want to delete this entry?';
$string['description'] = 'Description';
$string['dimensions'] = 'Dimensions';
$string['draft'] = 'Draft';
$string['edit'] = 'Edit';
$string['editblogpost'] = 'Edit journal entry';
$string['entriesimportedfromleapexport'] = 'Entries imported from a LEAP export that were not able to be imported elsewhere';
$string['errorsavingattachments'] = 'An error occurred while saving journal entry attachments';
$string['horizontalspace'] = 'Horizontal space';
$string['insert'] = 'Insert';
$string['insertimage'] = 'Insert image';
$string['moreoptions'] = 'More options';
$string['mustspecifytitle'] = 'You must specify a title for your entry';
$string['mustspecifycontent'] = 'You must specify some content for your entry';
$string['name'] = 'Name';
$string['newattachmentsexceedquota'] = 'The total size of the new files that you have uploaded to this entry would exceed your quota. You may be able to save the entry if you remove some of the attachments you have just added.';
$string['newblog'] = 'New journal';
$string['newblogpost'] = 'New journal entry in journal "%s"';
$string['newerposts'] = 'Newer entries';
$string['nodefaultblogfound'] = 'No default journal found. This is a bug in the system. To fix it, you need to enable the multiple journals option on the <a href="%saccount/">account settings</a> page.';
$string['nopostsyet'] = 'No entries yet.';
$string['addone'] = 'Add one';
$string['noimageshavebeenattachedtothispost'] = 'No images have been attached to this entry. You need to upload or attach an image to the entry before you can insert it.';
$string['nofilesattachedtothispost'] = 'No attached files';
$string['noresults'] = 'No journal entries found';
$string['olderposts'] = 'Older entries';
$string['post'] = 'entry';
$string['postbody'] = 'Entry';
$string['postbodydesc'] = ' ';
$string['postedon'] = 'Posted on';
$string['postedbyon'] = 'Posted by %s on %s';
$string['posttitle'] = 'Title';
$string['posts'] = 'entries';
$string['publish'] = 'Publish';
$string['publishfailed'] = 'An error occurred. Your entry was not published';
$string['publishblogpost?'] = 'Are you sure you want to publish this entry?';
$string['published'] = 'Published';
$string['remove'] = 'Remove';
$string['save'] = 'Save';
$string['saveandpublish'] = 'Save and publish';
$string['saveasdraft'] = 'Save as draft';
$string['savepost'] = 'Save entry';
$string['savesettings'] = 'Save settings';
$string['settings'] = 'Settings';
$string['thisisdraft'] = 'This entry is a draft';
$string['thisisdraftdesc'] = 'When your entry is a draft, no one except you can see it.';
$string['title'] = 'Title';
$string['update'] = 'Update';
$string['verticalspace'] = 'Vertical space';
$string['viewblog'] = 'View journal';
$string['youarenottheownerofthisblog'] = 'You are not the owner of this journal';
$string['youarenottheownerofthisblogpost'] = 'You are not the owner of this journal entry';
$string['cannotdeleteblogpost'] = 'An error occurred removing this journal entry.';

$string['baseline'] = 'Baseline';
$string['top'] = 'Top';
$string['middle'] = 'Middle';
$string['bottom'] = 'Bottom';
$string['texttop'] = 'Text top';
$string['textbottom'] = 'Text bottom';
$string['left'] = 'Left';
$string['right'] = 'Right';
$string['src'] = 'Image URL';
$string['image_list'] = 'Attached image';
$string['alt'] = 'Description';

$string['copyfull'] = 'Others will get their own copy of your %s';
$string['copyreference'] = 'Others may display your %s in their page';
$string['copynocopy'] = 'Skip this block entirely when copying the page';

$string['viewposts'] = 'Copied entries (%s)';
$string['postscopiedfromview'] = 'Entries copied from %s';

$string['youhavenoblogs'] = 'You have no journals.';
$string['youhaveoneblog'] = 'You have 1 journal.';
$string['youhaveblogs'] = 'You have %s journals.';

$string['feedsnotavailable'] = 'Feeds are not available for this artefact type.';
$string['feedrights'] = 'Copyright %s.';

$string['enablemultipleblogstext'] = 'You have one journal. If you would like to start a second one, enable the multiple journals option on the <a href="%saccount/">account settings</a> page.';
